@@ -172,7 +172,7 @@ class TestSparkSubmitHook:
     @patch(
         "airflow.providers.apache.spark.hooks.spark_submit.os.getenv", return_value="/tmp/airflow_krb5_ccache"
     )
-    def test_build_spark_submit_command(self, mock_get_env):
+    def test_build_spark_submit_command(self, mock_get_env, sdk_connection_not_found):
         # Given
         hook = SparkSubmitHook(**self._config)
 
@@ -291,13 +291,14 @@ class TestSparkSubmitHook:
 
     @pytest.mark.db_test
     @patch("airflow.providers.apache.spark.hooks.spark_submit.subprocess.Popen")
-    def test_spark_process_runcmd(self, mock_popen):
+    def test_spark_process_runcmd(self, mock_popen, sdk_connection_not_found):
         # Given
         mock_popen.return_value.stdout = StringIO("stdout")
         mock_popen.return_value.stderr = StringIO("stderr")
         mock_popen.return_value.wait.return_value = 0
 
         # When
+
         hook = SparkSubmitHook(conn_id="")
         hook.submit()
 
@@ -311,7 +312,7 @@ class TestSparkSubmitHook:
         )
 
     @pytest.mark.db_test
-    def test_resolve_should_track_driver_status(self):
+    def test_resolve_should_track_driver_status(self, sdk_connection_not_found):
         # Given
         hook_default = SparkSubmitHook(conn_id="")
         hook_spark_yarn_cluster = SparkSubmitHook(conn_id="spark_yarn_cluster")
@@ -347,7 +348,7 @@ class TestSparkSubmitHook:
         assert should_track_driver_status_spark_standalone_cluster is True
 
     @pytest.mark.db_test
-    def test_resolve_connection_yarn_default(self):
+    def test_resolve_connection_yarn_default(self, sdk_connection_not_found):
         # Given
         hook = SparkSubmitHook(conn_id="")
 
@@ -535,11 +536,11 @@ class TestSparkSubmitHook:
         SparkSubmitHook(conn_id="spark_binary_set", spark_binary="another-custom-spark-submit")
 
     def test_resolve_connection_spark_binary_extra_not_allowed_runtime_error(self):
-        with pytest.raises(RuntimeError):
+        with pytest.raises(ValueError):
             SparkSubmitHook(conn_id="spark_custom_binary_set")
 
     def test_resolve_connection_spark_home_not_allowed_runtime_error(self):
-        with pytest.raises(RuntimeError):
+        with pytest.raises(ValueError):
             SparkSubmitHook(conn_id="spark_home_set")
 
     def test_resolve_connection_spark_binary_default_value_override(self):
